pub(crate) struct Aes256GcmNonce(Nonce<Aes256Gcm>);Expand description
A 96-bit AES-256-GCM nonce.
AES-256-GCM has a short (96-bit) nonce, so a fresh nonce must be used for every message
encrypted under a given key to avoid catastrophic nonce reuse. Generate a fresh nonce with
Aes256GcmNonce::make for each encryption.
Tuple Fields
0: Nonce<Aes256Gcm>Implementations